agentle.agents.knowledge.static\_knowledge
==========================================

.. automodule:: agentle.agents.knowledge.static_knowledge

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
      urlparse
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      Path
      StaticKnowledge
   